Index: mandoline/ui/omnibox/omnibox_application.cc |
diff --git a/mandoline/ui/omnibox/omnibox_application.cc b/mandoline/ui/omnibox/omnibox_application.cc |
index c3b42de5737b26fb1ccb783cfeb27189e9639d08..18930e3eb31b1398368524fd7724b7bc11ffe610 100644 |
--- a/mandoline/ui/omnibox/omnibox_application.cc |
+++ b/mandoline/ui/omnibox/omnibox_application.cc |
@@ -26,7 +26,7 @@ |
//////////////////////////////////////////////////////////////////////////////// |
// OmniboxImpl |
-class OmniboxImpl : public mus::ViewTreeDelegate, |
+class OmniboxImpl : public mojo::ViewTreeDelegate, |
public views::LayoutManager, |
public views::TextfieldController, |
public Omnibox { |
@@ -37,9 +37,9 @@ |
~OmniboxImpl() override; |
private: |
- // Overridden from mus::ViewTreeDelegate: |
- void OnEmbed(mus::View* root) override; |
- void OnConnectionLost(mus::ViewTreeConnection* connection) override; |
+ // Overridden from mojo::ViewTreeDelegate: |
+ void OnEmbed(mojo::View* root) override; |
+ void OnConnectionLost(mojo::ViewTreeConnection* connection) override; |
// Overridden from views::LayoutManager: |
gfx::Size GetPreferredSize(const views::View* view) const override; |
@@ -59,7 +59,7 @@ |
scoped_ptr<AuraInit> aura_init_; |
mojo::ApplicationImpl* app_; |
- mus::View* root_; |
+ mojo::View* root_; |
mojo::String url_; |
views::Textfield* edit_; |
mojo::Binding<Omnibox> binding_; |
@@ -110,9 +110,9 @@ |
OmniboxImpl::~OmniboxImpl() {} |
//////////////////////////////////////////////////////////////////////////////// |
-// OmniboxImpl, mus::ViewTreeDelegate implementation: |
- |
-void OmniboxImpl::OnEmbed(mus::View* root) { |
+// OmniboxImpl, mojo::ViewTreeDelegate implementation: |
+ |
+void OmniboxImpl::OnEmbed(mojo::View* root) { |
root_ = root; |
if (!aura_init_.get()) { |
@@ -148,7 +148,7 @@ |
ShowWindow(); |
} |
-void OmniboxImpl::OnConnectionLost(mus::ViewTreeConnection* connection) { |
+void OmniboxImpl::OnConnectionLost(mojo::ViewTreeConnection* connection) { |
root_ = nullptr; |
} |
@@ -190,7 +190,7 @@ |
void OmniboxImpl::GetViewTreeClient( |
mojo::InterfaceRequest<mojo::ViewTreeClient> request) { |
- mus::ViewTreeConnection::Create(this, request.Pass()); |
+ mojo::ViewTreeConnection::Create(this, request.Pass()); |
} |
void OmniboxImpl::ShowForURL(const mojo::String& url) { |